@@ -1,6 +1,6 @@
 
 /* Compiler implementation of the D programming language
- * Copyright (C) 2017-2022 by The D Language Foundation, All Rights Reserved
+ * Copyright (C) 2017-2023 by The D Language Foundation, All Rights Reserved
  * written by Walter Bright
  * https://www.digitalmars.com
  * Distributed under the Boost Software License, Version 1.0.
@@ -85,6 +85,7 @@ struct Id
     static Identifier *udaOptStrategy;
     static Identifier *udaTarget;
     static Identifier *udaAssumeUsed;
+    static Identifier *udaCallingConvention;
     static Identifier *udaWeak;
     static Identifier *udaAllocSize;
     static Identifier *udaLLVMAttr;
@@ -96,6 +97,7 @@ struct Id
     static Identifier *udaDynamicCompileEmit;
     static Identifier *udaHidden;
     static Identifier *udaNoSanitize;
+    static Identifier *udaNoSplitStack;
     static Identifier *io;
 #endif
 };
