@@ -13,13 +13,14 @@
 
 #pragma once
 
-#include "gen/cl_helpers.h"
+#include "driver/cl_helpers.h"
 #include "llvm/Transforms/Instrumentation.h"
 
 class FuncDeclaration;
 namespace llvm {
 class raw_ostream;
 class StringRef;
+enum class AsanDetectStackUseAfterReturnMode;
 }
 
 namespace opts {
@@ -37,6 +38,8 @@ enum SanitizerCheck : SanitizerBits {
 };
 extern SanitizerBits enabledSanitizers;
 
+extern cl::opt<llvm::AsanDetectStackUseAfterReturnMode> fSanitizeAddressUseAfterReturn;
+
 inline bool isAnySanitizerEnabled() { return enabledSanitizers; }
 inline bool isSanitizerEnabled(SanitizerBits san) {
   return enabledSanitizers & san;
