@@ -47,10 +47,19 @@
 
 using CodeGenFileType = llvm::CodeGenFileType;
 
+#if LDC_LLVM_VER < 1700
 static llvm::cl::opt<bool>
     NoIntegratedAssembler("no-integrated-as", llvm::cl::ZeroOrMore,
                           llvm::cl::Hidden,
                           llvm::cl::desc("Disable integrated assembler"));
+#else
+namespace llvm {
+namespace codegen {
+bool getDisableIntegratedAS();
+}
+}
+#define NoIntegratedAssembler llvm::codegen::getDisableIntegratedAS()
+#endif
 
 namespace {
 
@@ -148,7 +157,7 @@ static void assemble(const std::string &asmpath, const std::string &objpath) {
   appendTargetArgsForGcc(args);
 
   // Run the compiler to assembly the program.
-  int R = executeToolAndWait(Loc(), getGcc(), args, global.params.verbose);
+  int R = executeToolAndWait(Loc(), getGcc(), args, global.params.v.verbose);
   if (R) {
     error(Loc(), "Error while invoking external assembler.");
     fatal();
