@@ -21,17 +21,6 @@
 
 //////////////////////////////////////////////////////////////////////////////
 
-dinteger_t undoStrideMul(const Loc &loc, Type *t, dinteger_t offset) {
-  assert(t->ty == TY::Tpointer);
-  const auto elemSize = t->nextOf()->size(loc);
-  assert((offset % elemSize) == 0 &&
-         "Expected offset by an integer amount of elements");
-
-  return offset / elemSize;
-}
-
-//////////////////////////////////////////////////////////////////////////////
-
 namespace {
 struct RVals {
   DRValue *lhs, *rhs;
@@ -89,33 +78,45 @@ DValue *emitPointerOffset(Loc loc, DValue *base, Expression *offset,
   // pointer elements. We try to undo this before resorting to
   // temporarily bitcasting the pointer to i8.
 
+  Type *const pointeeType = base->type->nextOf();
+
+  LLType * llBaseTy = DtoMemType(pointeeType);
   LLValue *llBase = nullptr;
   LLValue *llOffset = nullptr;
   LLValue *llResult = nullptr;
 
   if (offset->isConst()) {
     llBase = DtoRVal(base);
-    dinteger_t byteOffset = offset->toInteger();
+    const dinteger_t byteOffset = offset->toInteger();
     if (byteOffset == 0) {
       llResult = llBase;
     } else {
-      llOffset = DtoConstSize_t(undoStrideMul(loc, base->type, byteOffset));
+      const auto pointeeSize = pointeeType->size(loc);
+      if (pointeeSize && byteOffset % pointeeSize == 0) { // can do a nice GEP
+        llOffset = DtoConstSize_t(byteOffset / pointeeSize);
+      } else { // need to cast base to i8*
+        llBaseTy = getI8Type();
+        llBase = DtoBitCast(llBase, getVoidPtrType());
+        llOffset = DtoConstSize_t(byteOffset);
+      }
     }
   } else {
-    Expression *noStrideInc = extractNoStrideInc(
-        offset, base->type->nextOf()->size(loc), negateOffset);
+    Expression *noStrideInc =
+        extractNoStrideInc(offset, pointeeType->size(loc), negateOffset);
     auto rvals =
         evalSides(base, noStrideInc ? noStrideInc : offset, loadLhsAfterRhs);
     llBase = DtoRVal(rvals.lhs);
     llOffset = DtoRVal(rvals.rhs);
-    if (!noStrideInc) // byte offset => cast base to i8*
+    if (!noStrideInc) { // byte offset => cast base to i8*
+      llBaseTy = getI8Type();
       llBase = DtoBitCast(llBase, getVoidPtrType());
+    }
   }
 
   if (!llResult) {
     if (negateOffset)
       llOffset = gIR->ir->CreateNeg(llOffset);
-    llResult = DtoGEP1(llBase, llOffset);
+    llResult = DtoGEP1(llBaseTy, llBase, llOffset);
   }
 
   return new DImValue(resultType, DtoBitCast(llResult, DtoType(resultType)));
@@ -368,9 +369,6 @@ LLValue *DtoBinFloatsEquals(const Loc &loc, DValue *lhs, DValue *rhs, EXP op) {
     LLValue *r = DtoRVal(rhs);
     res = (op == EXP::equal ? gIR->ir->CreateFCmpOEQ(l, r)
                             : gIR->ir->CreateFCmpUNE(l, r));
-    if (lhs->type->toBasetype()->ty == TY::Tvector) {
-      res = mergeVectorEquals(res, op);
-    }
   } else {
     const auto cmpop =
         op == EXP::identity ? llvm::ICmpInst::ICMP_EQ : llvm::ICmpInst::ICMP_NE;
