@@ -19,11 +19,13 @@
 class Type;
 class Dsymbol;
 class VarDeclaration;
+class BitFieldDeclaration;
 class FuncDeclaration;
 
 namespace llvm {
 class Value;
 class Type;
+class IntegerType;
 class Constant;
 }
 
@@ -34,6 +36,8 @@ class DConstValue;
 class DNullValue;
 class DLValue;
 class DSpecialRefValue;
+class DBitFieldLValue;
+class DDcomputeLValue;
 class DSliceValue;
 class DFuncValue;
 
@@ -57,6 +61,8 @@ public:
 
   virtual DLValue *isLVal() { return nullptr; }
   virtual DSpecialRefValue *isSpecialRef() { return nullptr; }
+  virtual DBitFieldLValue *isBitFieldLVal() { return nullptr; }
+  virtual DDcomputeLValue *isDDcomputeLVal() { return nullptr; }
 
   virtual DRValue *isRVal() { return nullptr; }
   virtual DImValue *isIm() { return nullptr; }
@@ -176,5 +182,34 @@ public:
   DSpecialRefValue *isSpecialRef() override { return this; }
 };
 
+/// Represents (very) special 'lvalues' for bit fields.
+class DBitFieldLValue : public DValue {
+public:
+  DBitFieldLValue(Type *t, llvm::Value *ptr, BitFieldDeclaration *bf);
+
+  DBitFieldLValue *isBitFieldLVal() override { return this; }
+
+  // Loads, masks and shifts the relevant bits from memory.
+  DRValue *getRVal() override;
+
+  // Masks and shifts the specified bits and stores them to memory.
+  void store(llvm::Value *value);
+
+private:
+  BitFieldDeclaration *const bf;
+  llvm::IntegerType *const intType; // covering all bytes from bf->offset to the
+                                    // byte the highest bit is in
+};
+
+/// Represents lvalues of address spaced pointers and pointers
+/// to address spaces other then 0
+class DDcomputeLValue : public DLValue {
+public:
+  llvm::Type *lltype;
+  DDcomputeLValue *isDDcomputeLVal() override { return this; }
+    DDcomputeLValue(Type *t, llvm::Type * llt, llvm::Value *v);
+  DRValue *getRVal() override;
+};
+
 inline llvm::Value *DtoRVal(DValue *v) { return v->getRVal()->val; }
 llvm::Value *DtoLVal(DValue *v);
