@@ -114,7 +114,12 @@ void cloneBlocks(const std::vector<llvm::BasicBlock *> &srcblocks,
       if (!newInst)
         newInst = Inst->clone();
 
+#if LDC_LLVM_VER < 1600
       nbb->getInstList().push_back(newInst);
+#else
+      newInst->insertInto(nbb, nbb->end());
+#endif
+
       VMap[Inst] = newInst; // Add instruction map to value.
       if (unwindTo)
         if (auto dest = getUnwindDest(Inst))
