@@ -25,6 +25,7 @@ class raw_ostream;
 
 namespace llvm {
 class Module;
+class TargetLibraryInfoImpl;
 }
 
 bool ldc_optimize_module(llvm::Module *m);
@@ -34,10 +35,6 @@ bool willInline();
 
 bool willCrossModuleInline();
 
-#if LDC_LLVM_VER < 1000
-llvm::FramePointer::FP whichFramePointersToEmit();
-#endif
-
 unsigned optLevel();
 
 bool isOptimizationEnabled();
@@ -47,3 +44,5 @@ llvm::CodeGenOpt::Level codeGenOptLevel();
 void verifyModule(llvm::Module *m);
 
 void outputOptimizationSettings(llvm::raw_ostream &hash_os);
+
+std::unique_ptr<llvm::TargetLibraryInfoImpl> createTLII(llvm::Module &M);
