@@ -920,7 +920,11 @@ void CodeGenPGO::loadRegionCounts(llvm::IndexedInstrProfReader *PGOReader,
   auto EC = RecordExpected.takeError();
 
   if (EC) {
+#if LDC_LLVM_VER >= 1700
+    auto IPE = std::get<0>(llvm::InstrProfError::take(std::move(EC)));
+#else
     auto IPE = llvm::InstrProfError::take(std::move(EC));
+#endif
     if (IPE == llvm::instrprof_error::unknown_function) {
       IF_LOG Logger::println("No profile data for function: %s",
                              FuncName.c_str());
