@@ -15,8 +15,9 @@
 #include "dmd/mtype.h"
 #include "dmd/target.h"
 #include "driver/cl_options.h"
+#include "driver/cl_options_instrumentation.h"
 #include "driver/linker.h"
-#include "gen/abi.h"
+#include "gen/abi/abi.h"
 #include "gen/irstate.h"
 #include "gen/llvmhelpers.h"
 #include <assert.h>
@@ -58,6 +59,10 @@ llvm::Type *getRealType(const llvm::Triple &triple) {
 
   case Triple::riscv32:
   case Triple::riscv64:
+#if LDC_LLVM_VER >= 1600
+  case Triple::loongarch32:
+  case Triple::loongarch64:
+#endif // LDC_LLVM_VER >= 1600
     return LLType::getFP128Ty(ctx);
 
   default:
@@ -101,7 +106,7 @@ void Target::_init(const Param &params) {
   realType = getRealType(triple);
   realsize = gDataLayout->getTypeAllocSize(realType);
   realpad = realsize - gDataLayout->getTypeStoreSize(realType);
-  realalignsize = gDataLayout->getABITypeAlignment(realType);
+  realalignsize = gDataLayout->getABITypeAlign(realType).value();
   classinfosize = 0; // unused
   maxStaticDataSize = std::numeric_limits<unsigned long long>::max();
 
@@ -127,10 +132,8 @@ void Target::_init(const Param &params) {
   const llvm::StringRef archName = triple.getArchName();
   architectureName = {archName.size(), archName.data()};
 
-  is64bit = triple.isArch64Bit();
   isLP64 = gDataLayout->getPointerSizeInBits() == 64;
   run_noext = !triple.isOSWindows();
-  omfobj = false;
 
   if (isMSVC) {
     obj_ext = {3, "obj"};
@@ -154,14 +157,16 @@ void Target::_init(const Param &params) {
   const auto IEEEdouble = &APFloat::IEEEdouble();
   const auto x87DoubleExtended = &APFloat::x87DoubleExtended();
   const auto IEEEquad = &APFloat::IEEEquad();
+  bool isOutOfRange = false;
 
   RealProperties.nan = CTFloat::nan;
   RealProperties.infinity = CTFloat::infinity;
 
   if (targetRealSemantics == IEEEdouble) {
-    RealProperties.max = CTFloat::parse("0x1.fffffffffffffp+1023");
-    RealProperties.min_normal = CTFloat::parse("0x1p-1022");
-    RealProperties.epsilon = CTFloat::parse("0x1p-52");
+    RealProperties.max =
+        CTFloat::parse("0x1.fffffffffffffp+1023", isOutOfRange);
+    RealProperties.min_normal = CTFloat::parse("0x1p-1022", isOutOfRange);
+    RealProperties.epsilon = CTFloat::parse("0x1p-52", isOutOfRange);
     RealProperties.dig = 15;
     RealProperties.mant_dig = 53;
     RealProperties.max_exp = 1024;
@@ -169,9 +174,10 @@ void Target::_init(const Param &params) {
     RealProperties.max_10_exp = 308;
     RealProperties.min_10_exp = -307;
   } else if (targetRealSemantics == x87DoubleExtended) {
-    RealProperties.max = CTFloat::parse("0x1.fffffffffffffffep+16383");
-    RealProperties.min_normal = CTFloat::parse("0x1p-16382");
-    RealProperties.epsilon = CTFloat::parse("0x1p-63");
+    RealProperties.max =
+        CTFloat::parse("0x1.fffffffffffffffep+16383", isOutOfRange);
+    RealProperties.min_normal = CTFloat::parse("0x1p-16382", isOutOfRange);
+    RealProperties.epsilon = CTFloat::parse("0x1p-63", isOutOfRange);
     RealProperties.dig = 18;
     RealProperties.mant_dig = 64;
     RealProperties.max_exp = 16384;
@@ -180,12 +186,12 @@ void Target::_init(const Param &params) {
     RealProperties.min_10_exp = -4931;
   } else if (targetRealSemantics == IEEEquad) {
     // FIXME: hex constants
-    RealProperties.max =
-        CTFloat::parse("1.18973149535723176508575932662800702e+4932");
-    RealProperties.min_normal =
-        CTFloat::parse("3.36210314311209350626267781732175260e-4932");
-    RealProperties.epsilon =
-        CTFloat::parse("1.92592994438723585305597794258492732e-34");
+    RealProperties.max = CTFloat::parse(
+        "1.18973149535723176508575932662800702e+4932", isOutOfRange);
+    RealProperties.min_normal = CTFloat::parse(
+        "3.36210314311209350626267781732175260e-4932", isOutOfRange);
+    RealProperties.epsilon = CTFloat::parse(
+        "1.92592994438723585305597794258492732e-34", isOutOfRange);
     RealProperties.dig = 33;
     RealProperties.mant_dig = 113;
     RealProperties.max_exp = 16384;
@@ -207,7 +213,7 @@ unsigned Target::alignsize(Type *type) {
   if (type->ty == TY::Tvoid) {
     return 1;
   }
-  return gDataLayout->getABITypeAlignment(DtoType(type));
+  return gDataLayout->getABITypeAlign(DtoType(type)).value();
 }
 
 /******************************
@@ -306,6 +312,11 @@ Expression *Target::getTargetInfo(const char *name_, const Loc &loc) {
         Loc(), static_cast<unsigned>(global.params.cplusplus), Type::tint32);
   }
 
+  if (name == "CET") {
+    auto cet = opts::fCFProtection.getValue();
+    return IntegerExp::create(loc, static_cast<unsigned>(cet), Type::tint32);
+  }
+
 #if LDC_LLVM_SUPPORTED_TARGET_SPIRV || LDC_LLVM_SUPPORTED_TARGET_NVPTX
   if (name == "dcomputeTargets") {
     Expressions* exps = createExpressions();
