@@ -288,7 +288,7 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
   // va_start instruction
   if (fndecl->llvmInternal == LLVMva_start) {
     if (e->arguments->length < 1 || e->arguments->length > 2) {
-      e->error("`va_start` instruction expects 1 (or 2) arguments");
+      error(e->loc, "`va_start` instruction expects 1 (or 2) arguments");
       fatal();
     }
     DLValue *ap = toElem((*e->arguments)[0])->isLVal(); // va_list
@@ -309,7 +309,7 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
   // va_copy instruction
   if (fndecl->llvmInternal == LLVMva_copy) {
     if (e->arguments->length != 2) {
-      e->error("`va_copy` instruction expects 2 arguments");
+      error(e->loc, "`va_copy` instruction expects 2 arguments");
       fatal();
     }
     DLValue *dest = toElem((*e->arguments)[0])->isLVal(); // va_list
@@ -323,11 +323,12 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
   // va_arg instruction
   if (fndecl->llvmInternal == LLVMva_arg) {
     if (e->arguments->length != 1) {
-      e->error("`va_arg` instruction expects 1 argument");
+      error(e->loc, "`va_arg` instruction expects 1 argument");
       fatal();
     }
     if (DtoIsInMemoryOnly(e->type)) {
-      e->error("`va_arg` instruction does not support structs and static arrays");
+      error(e->loc,
+            "`va_arg` instruction does not support structs and static arrays");
       fatal();
     }
     DLValue *ap = toElem((*e->arguments)[0])->isLVal(); // va_list
@@ -341,7 +342,7 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
   // va_end instruction
   if (fndecl->llvmInternal == LLVMva_end) {
     if (e->arguments->length != 1) {
-      e->error("`va_end` instruction expects 1 argument");
+      error(e->loc, "`va_end` instruction expects 1 argument");
       fatal();
     }
     DLValue *ap = toElem((*e->arguments)[0])->isLVal(); // va_list
@@ -355,7 +356,7 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
   // C alloca
   if (fndecl->llvmInternal == LLVMalloca) {
     if (e->arguments->length != 1) {
-      e->error("`alloca` expects 1 argument");
+      error(e->loc, "`alloca` expects 1 argument");
       fatal();
     }
     Expression *exp = (*e->arguments)[0];
@@ -372,7 +373,7 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
   // fence instruction
   if (fndecl->llvmInternal == LLVMfence) {
     if (e->arguments->length < 1 || e->arguments->length > 2) {
-      e->error("`fence` instruction expects 1 (or 2) arguments");
+      error(e->loc, "`fence` instruction expects 1 (or 2) arguments");
       fatal();
     }
     auto atomicOrdering =
@@ -388,7 +389,7 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
   // atomic store instruction
   if (fndecl->llvmInternal == LLVMatomic_store) {
     if (e->arguments->length != 3) {
-      e->error("atomic store instruction expects 3 arguments");
+      error(e->loc, "atomic store instruction expects 3 arguments");
       fatal();
     }
     Expression *exp1 = (*e->arguments)[0];
@@ -408,7 +409,7 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
       auto lval = makeLValue(exp1->loc, dval);
       val = DtoLoad(atype, DtoBitCast(lval, intPtrType));
     } else {
-      e->error(
+      error(e->loc,
           "atomic store only supports types of size 1/2/4/8/16 bytes, not `%s`",
           exp1->type->toChars());
       fatal();
@@ -425,7 +426,7 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
   // atomic load instruction
   if (fndecl->llvmInternal == LLVMatomic_load) {
     if (e->arguments->length != 2) {
-      e->error("atomic load instruction expects 2 arguments");
+      error(e->loc, "atomic load instruction expects 2 arguments");
       fatal();
     }
 
@@ -442,9 +443,10 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
         ptr = DtoBitCast(ptr, intPtrType);
         loadedType = getAtomicType(pointeeType);
       } else {
-        e->error("atomic load only supports types of size 1/2/4/8/16 bytes, "
-                 "not `%s`",
-                 retType->toChars());
+        error(e->loc,
+              "atomic load only supports types of size 1/2/4/8/16 bytes, "
+              "not `%s`",
+              retType->toChars());
         fatal();
       }
     }
@@ -467,11 +469,11 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
   // cmpxchg instruction
   if (fndecl->llvmInternal == LLVMatomic_cmp_xchg) {
     if (e->arguments->length != 6) {
-      e->error("`cmpxchg` instruction expects 6 arguments");
+      error(e->loc, "`cmpxchg` instruction expects 6 arguments");
       fatal();
     }
     if (e->type->ty != TY::Tstruct) {
-      e->error("`cmpxchg` instruction returns a struct");
+      error(e->loc, "`cmpxchg` instruction returns a struct");
       fatal();
     }
     Expression *exp1 = (*e->arguments)[0];
@@ -501,9 +503,9 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
       auto lval = makeLValue(exp3->loc, dval);
       val = DtoLoad(atype, DtoBitCast(lval, intPtrType));
     } else {
-      e->error(
-          "`cmpxchg` only supports types of size 1/2/4/8/16 bytes, not `%s`",
-          exp2->type->toChars());
+      error(e->loc,
+            "`cmpxchg` only supports types of size 1/2/4/8/16 bytes, not `%s`",
+            exp2->type->toChars());
       fatal();
     }
 
@@ -531,7 +533,7 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
   // atomicrmw instruction
   if (fndecl->llvmInternal == LLVMatomic_rmw) {
     if (e->arguments->length != 3) {
-      e->error("`atomicrmw` instruction expects 3 arguments");
+      error(e->loc, "`atomicrmw` instruction expects 3 arguments");
       fatal();
     }
 
@@ -542,8 +544,8 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
     int op = 0;
     for (;; ++op) {
       if (ops[op] == nullptr) {
-        e->error("unknown `atomicrmw` operation `%s`",
-                 fndecl->intrinsicName);
+        error(e->loc, "unknown `atomicrmw` operation `%s`",
+              fndecl->intrinsicName);
         fatal();
       }
       if (strcmp(fndecl->intrinsicName, ops[op]) == 0) {
@@ -572,7 +574,7 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
       fndecl->llvmInternal == LLVMbitop_btc ||
       fndecl->llvmInternal == LLVMbitop_bts) {
     if (e->arguments->length != 2) {
-      e->error("bitop intrinsic expects 2 arguments");
+      error(e->loc, "bitop intrinsic expects 2 arguments");
       fatal();
     }
 
@@ -627,7 +629,7 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
 
   if (fndecl->llvmInternal == LLVMbitop_vld) {
     if (e->arguments->length != 1) {
-      e->error("`bitop.vld` intrinsic expects 1 argument");
+      error(e->loc, "`bitop.vld` intrinsic expects 1 argument");
       fatal();
     }
     // TODO: Check types
@@ -640,7 +642,7 @@ bool DtoLowerMagicIntrinsic(IRState *p, FuncDeclaration *fndecl, CallExp *e,
 
   if (fndecl->llvmInternal == LLVMbitop_vst) {
     if (e->arguments->length != 2) {
-      e->error("`bitop.vst` intrinsic expects 2 arguments");
+      error(e->loc, "`bitop.vst` intrinsic expects 2 arguments");
       fatal();
     }
     // TODO: Check types
