@@ -82,23 +82,26 @@ void setVisibility(Dsymbol *sym, llvm::GlobalObject *obj);
 LLIntegerType *DtoSize_t();
 LLStructType *DtoModuleReferenceType();
 
-// Returns the pointee type of the specified pointer value.
-LLType *getPointeeType(LLValue *pointer);
-
 // getelementptr helpers
-LLValue *DtoGEP1(LLValue *ptr, LLValue *i0, const char *name = "",
-                 llvm::BasicBlock *bb = nullptr);
-LLValue *DtoGEP(LLValue *ptr, LLValue *i0, LLValue *i1, const char *name = "",
-                llvm::BasicBlock *bb = nullptr);
+LLValue *DtoGEP1(LLType *pointeeTy, LLValue *ptr, LLValue *i0,
+                 const char *name = "", llvm::BasicBlock *bb = nullptr);
+LLValue *DtoGEP(LLType *pointeeTy, LLValue *ptr, LLValue *i0, LLValue *i1,
+                const char *name = "", llvm::BasicBlock *bb = nullptr);
 
-LLValue *DtoGEP1(LLValue *ptr, unsigned i0, const char *name = "",
-                 llvm::BasicBlock *bb = nullptr);
-LLValue *DtoGEP(LLValue *ptr, unsigned i0, unsigned i1, const char *name = "",
-                llvm::BasicBlock *bb = nullptr);
-LLConstant *DtoGEP(LLConstant *ptr, unsigned i0, unsigned i1);
+LLValue *DtoGEP1(LLType *pointeeTy, LLValue *ptr, unsigned i0,
+                 const char *name = "", llvm::BasicBlock *bb = nullptr);
+LLValue *DtoGEP(LLType *pointeeTy, LLValue *ptr, unsigned i0, unsigned i1,
+                const char *name = "", llvm::BasicBlock *bb = nullptr);
+LLConstant *DtoGEP(LLType *pointeeTy, LLConstant *ptr, unsigned i0,
+                   unsigned i1);
+
+LLValue *DtoGEP1i64(LLType *pointeeTy, LLValue *ptr, uint64_t i0,
+                    const char *name = "", llvm::BasicBlock *bb = nullptr);
 
 // to constant helpers
 LLConstantInt *DtoConstSize_t(uint64_t);
+LLConstantInt *DtoConstUlong(uint64_t i);
+LLConstantInt *DtoConstLong(int64_t i);
 LLConstantInt *DtoConstUint(unsigned i);
 LLConstantInt *DtoConstInt(int i);
 LLConstantInt *DtoConstUbyte(unsigned char i);
@@ -109,9 +112,11 @@ LLConstant *DtoConstString(const char *);
 LLConstant *DtoConstBool(bool);
 
 // llvm wrappers
-LLValue *DtoLoad(LLValue *src, const char *name = "");
-LLValue *DtoVolatileLoad(LLValue *src, const char *name = "");
-LLValue *DtoAlignedLoad(LLValue *src, const char *name = "");
+class DLValue;
+LLValue *DtoLoad(DLValue *src, const char *name = "");
+LLValue *DtoLoad(LLType *, LLValue *src, const char *name = "");
+LLValue *DtoVolatileLoad(LLType *, LLValue *src, const char *name = "");
+LLValue *DtoAlignedLoad(LLType *type, LLValue *src, const char *name = "");
 void DtoStore(LLValue *src, LLValue *dst);
 void DtoVolatileStore(LLValue *src, LLValue *dst);
 void DtoStoreZextI8(LLValue *src, LLValue *dst);
@@ -143,6 +148,7 @@ llvm::Argument *isaArgument(LLValue *v);
 LLGlobalVariable *isaGlobalVar(LLValue *v);
 
 // llvm::T::get(...) wrappers
+LLType *getI8Type();
 LLPointerType *getPtrToType(LLType *t);
 LLPointerType *getVoidPtrType();
 llvm::ConstantPointerNull *getNullPtr(LLType *t);
@@ -160,7 +166,7 @@ unsigned int getABITypeAlign(LLType *t);
 LLValue *DtoAggrPair(LLType *type, LLValue *V1, LLValue *V2,
                      const char *name = "");
 LLValue *DtoAggrPair(LLValue *V1, LLValue *V2, const char *name = "");
-LLValue *DtoAggrPaint(LLValue *aggr, LLType *as);
+LLValue *DtoSlicePaint(LLValue *aggr, LLType *as);
 
 /**
  * Generates a call to llvm.memset.i32 (or i64 depending on architecture).
@@ -177,7 +183,7 @@ void DtoMemSet(LLValue *dst, LLValue *val, LLValue *nbytes, unsigned align = 1);
  * @param nbytes Number of bytes to overwrite.
  * @param align The minimum alignment of the destination memory.
  */
-void DtoMemSetZero(LLValue *dst, LLValue *nbytes, unsigned align = 1);
+void DtoMemSetZero(LLType *type, LLValue *dst, LLValue *nbytes, unsigned align = 1);
 
 /**
  * The same as DtoMemSetZero but figures out the size itself based on the
@@ -185,7 +191,7 @@ void DtoMemSetZero(LLValue *dst, LLValue *nbytes, unsigned align = 1);
  * @param dst Destination memory.
  * @param align The minimum alignment of the destination memory.
  */
-void DtoMemSetZero(LLValue *dst, unsigned align = 1);
+void DtoMemSetZero(LLType *type, LLValue *dst, unsigned align = 1);
 
 /**
  * Generates a call to llvm.memcpy.i32 (or i64 depending on architecture).
@@ -204,7 +210,7 @@ void DtoMemCpy(LLValue *dst, LLValue *src, LLValue *nbytes, unsigned align = 1);
  * @param withPadding Use the dst pointee's padded size, not its store size.
  * @param align The minimum alignment of the source and destination memory.
  */
-void DtoMemCpy(LLValue *dst, LLValue *src, bool withPadding = false,
+void DtoMemCpy(LLType *type, LLValue *dst, LLValue *src, bool withPadding = false,
                unsigned align = 1);
 
 /**
