@@ -67,15 +67,10 @@ IrTypeClass *IrTypeClass::get(ClassDeclaration *cd) {
   const auto t = new IrTypeClass(cd);
   getIrType(cd->type) = t;
 
-  IF_LOG Logger::println("Instance size: %u", cd->structsize);
+  const unsigned instanceSize = cd->structsize;
+  IF_LOG Logger::println("Instance size: %u", instanceSize);
 
-  // This class may contain an align declaration. See GitHub #726.
-  t->packed = false;
-  for (auto base = cd; base != nullptr && !t->packed; base = base->baseClass) {
-    t->packed = isPacked(base);
-  }
-
-  AggrTypeBuilder builder(t->packed);
+  AggrTypeBuilder builder;
 
   // add vtbl
   builder.addType(llvm::PointerType::get(t->vtbl_type, 0), target.ptrsize);
@@ -88,20 +83,19 @@ IrTypeClass *IrTypeClass::get(ClassDeclaration *cd) {
     // classes have monitor and fields
     if (!cd->isCPPclass() && !cd->isCPPinterface()) {
       // add monitor
-      builder.addType(
-          llvm::PointerType::get(llvm::Type::getInt8Ty(gIR->context()), 0),
-          target.ptrsize);
+      builder.addType(getVoidPtrType(), target.ptrsize);
     }
 
     // add data members recursively
     t->addClassData(builder, cd);
 
     // add tail padding
-    builder.addTailPadding(cd->structsize);
+    if (instanceSize) // can be 0 for opaque classes
+      builder.addTailPadding(instanceSize);
   }
 
   // set struct body and copy GEP indices
-  isaStruct(t->type)->setBody(builder.defaultTypes(), t->packed);
+  isaStruct(t->type)->setBody(builder.defaultTypes(), builder.isPacked());
   t->varGEPIndices = builder.varGEPIndices();
 
   IF_LOG Logger::cout() << "class type: " << *t->type << std::endl;
