@@ -6,7 +6,7 @@ int fromC_ref(const std::string_view&);
 int sumOfElements_ref(const std::string_view& str)
 {
     int r = 0;
-    for (size_t i = 0; i < str.size(); ++i)
+    for (std::size_t i = 0; i < str.size(); ++i)
         r += str[i];
     return r;
 }
